==> reverie_dreams-0.4.3%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/entity/ai/goal/GhostStatusEffectTargetGoal.java <==
package cc.thonly.reverie_dreams.entity.ai.goal;

import cc.thonly.reverie_dreams.data.ModTags;
import net.minecraft.class_1291;
import net.minecraft.class_1304;
import net.minecraft.class_1308;
import net.minecraft.class_1309;
import net.minecraft.class_1799;
import net.minecraft.class_4051;
import net.minecraft.class_6880;
import org.jetbrains.annotations.Nullable;

public class GhostStatusEffectTargetGoal<T extends class_1309> extends StatusEffectTargetGoal<T> {
    private static final int DEFAULT_RECIPROCAL_CHANCE = 10;

    public GhostStatusEffectTargetGoal(class_1308 mob, Class<T> targetClass, boolean checkVisibility, @Nullable class_6880<class_1291> requiredEffect) {
        this(mob, targetClass, DEFAULT_RECIPROCAL_CHANCE, checkVisibility, false, null, requiredEffect);
    }

    public GhostStatusEffectTargetGoal(class_1308 mob, Class<T> targetClass, int reciprocalChance, boolean checkVisibility, boolean checkCanNavigate, @Nullable class_4051.class_10254 targetPredicate, @Nullable class_6880<class_1291> requiredEffect) {
        super(mob, targetClass, reciprocalChance, checkVisibility, checkCanNavigate, targetPredicate, requiredEffect);
    }

    @Override
    public void method_6269() {
        if (this.targetEntity != null) {
            var hasSilver = hasSilverArmor(this.targetEntity);
            System.out.println(hasSilver);
            if (!hasSilver) {
                super.method_6269();
            }
        }
    }

    public static boolean hasSilverArmor(class_1309 targetEntity) {
        if (!targetEntity.method_5805()) return false;
        final var tag = ModTags.ItemTypeTag.SILVER_ARMOR;
        class_1799 head = targetEntity.method_6118(class_1304.field_6169);
        class_1799 chest = targetEntity.method_6118(class_1304.field_6174);
        class_1799 legs = targetEntity.method_6118(class_1304.field_6172);
        class_1799 feet = targetEntity.method_6118(class_1304.field_6166);

        return head.method_31573(tag) || chest.method_31573(tag) || legs.method_31573(tag) || feet.method_31573(tag);
    }
}

==> reverie_dreams-0.4.6%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/entity/ai/goal/GhostStatusEffectTargetGoal.java <==
package cc.thonly.reverie_dreams.entity.ai.goal;

import cc.thonly.reverie_dreams.registry.tag.RDItemTags;
import net.minecraft.class_1291;
import net.minecraft.class_1304;
import net.minecraft.class_1308;
import net.minecraft.class_1309;
import net.minecraft.class_1799;
import net.minecraft.class_4051;
import net.minecraft.class_6880;
import org.jetbrains.annotations.Nullable;

public class GhostStatusEffectTargetGoal<T extends class_1309> extends StatusEffectTargetGoal<T> {
    private static final int DEFAULT_RECIPROCAL_CHANCE = 10;

    public GhostStatusEffectTargetGoal(class_1308 mob, Class<T> targetClass, boolean checkVisibility, @Nullable class_6880<class_1291> requiredEffect) {
        this(mob, targetClass, DEFAULT_RECIPROCAL_CHANCE, checkVisibility, false, null, requiredEffect);
    }

    public GhostStatusEffectTargetGoal(class_1308 mob, Class<T> targetClass, int reciprocalChance, boolean checkVisibility, boolean checkCanNavigate, @Nullable class_4051.class_10254 targetPredicate, @Nullable class_6880<class_1291> requiredEffect) {
        super(mob, targetClass, reciprocalChance, checkVisibility, checkCanNavigate, targetPredicate, requiredEffect);
    }

    @Override
    public void method_6269() {
        if (this.targetEntity != null) {
            var hasSilver = hasSilverArmor(this.targetEntity);
            System.out.println(hasSilver);
            if (!hasSilver) {
                super.method_6269();
            }
        }
    }

    public static boolean hasSilverArmor(class_1309 targetEntity) {
        if (!targetEntity.method_5805()) return false;
        final var tag = RDItemTags.SILVER_ARMOR;
        class_1799 head = targetEntity.method_6118(class_1304.field_6169);
        class_1799 chest = targetEntity.method_6118(class_1304.field_6174);
        class_1799 legs = targetEntity.method_6118(class_1304.field_6172);
        class_1799 feet = targetEntity.method_6118(class_1304.field_6166);

        return head.method_31573(tag) || chest.method_31573(tag) || legs.method_31573(tag) || feet.method_31573(tag);
    }
}
